Pyrseas was started in 2010.

The PRIMARY AUTHORS are or have been:

    * Joe Abbate
    * Ronan Dunklau
    * Douglas Fraser
    * Mark Goldfinch
    * Ryan Graham
    * Andjelko Horvat
    * Roger Hunwicks
    * Ghislain Leveque
    * Chris Mayo
    * Philippe Pepiot
    * Andrey Popp
    * Ross J. Reedstrom
    * github.com/shirkey
    * Denis Smirnov
    * Feike Steenbergen
    * Paulo Tioseco
    * Daniele Varrazzo
    * Vasiliy Yeremeyev

A big THANK YOU goes to the following individuals that provided
inspiration for some of the features and design of Pyrseas:

    * Ken Downs for creating the Andromeda project.

    * Robert Brewer for Post-Facto.
